@@ -10,7 +10,7 @@ class UserLoginResponse(NamedTuple):
     refresh_token: str
     access_token: str
     expires_in: int
-    loggedin: bool = False
+    logged_in: bool = False
 
 class XblAuthenticateResponse(NamedTuple):
     user_hash: str
@@ -21,5 +21,10 @@ class XSTSAuthenticateResponse(NamedTuple):
     token: str
 
 class UserProfile(NamedTuple):
+    username: str
+    uuid: str
+
+class UserProfileInformation(NamedTuple):
+    access_token: str
     username: str
     uuid: str
\ No newline at end of file
